==> tlmsp-apache-httpd-2.0.25.tar: tlmsp-apache-httpd-2.0.25/support/win32/ApacheMonitor.h <==
#define IDD_DLGSERVICES		        101
#define IDS_APMONITORTITLE              102
#define IDS_APMONITORCLASS              103
#define IDM_RESTORE                     104
#define IDM_EXIT                        105
#define IDI_APSRVMON                    106
#define IDI_ICOSTOP                     107
#define IDI_ICORUN                      108
#define IDC_STATBAR                     109
#define IDC_SSTATUS                     110
#define IDB_BMPSTOP                     111
#define IDB_BMPRUN                      112
#define IDB_BMPHEADER                   113
#define IDL_SERVICES                    114
#define IDL_STDOUT                      115
#define IDC_SSTART                      116
#define IDC_SSTOP                       117
#define IDC_SRESTART                    118
#define IDC_SEXIT                       119
#define IDC_SMANAGER                    120
#define IDS_MSG_FIRST                   256
#define IDS_MSG_APPRUNNING              256
#define IDS_MSG_ERROR                   257
#define IDS_MSG_RUNNINGALL              258
#define IDS_MSG_RUNNING                 259
#define IDS_MSG_RUNNINGNONE             260
#define IDS_MSG_NOSERVICES              261
#define IDS_MSG_MNUSERVICES             262
#define IDS_MSG_MNUSHOW                 263
#define IDS_MSG_MNUEXIT                 264
#define IDS_MSG_SRVSTART                265
#define IDS_MSG_SRVSTARTED              266
#define IDS_MSG_SRVSTOP                 267
#define IDS_MSG_SRVSTOPPED              268
#define IDS_MSG_SRVRESTART              269
#define IDS_MSG_SRVRESTARTED            270
#define IDS_MSG_SRVFAILED               271
#define IDS_MSG_SSTART                  272
#define IDS_MSG_SSTOP                   273
#define IDS_MSG_SRESTART                274
#define IDS_MSG_SERVICES                275
#define IDS_MSG_LAST                    275
#define IDM_SM_SERVICE                  0x1100
#define IDM_SM_START                    0x1200
#define IDM_SM_STOP                     0x1400
#define IDM_SM_RESTART                  0x1800
#define IDC_STATIC                      -1

==> tlmsp-apache-httpd-2.0.27.tar: tlmsp-apache-httpd-2.0.27/support/win32/ApacheMonitor.h <==
#define IDD_DLGSERVICES                 101
#define IDS_APMONITORTITLE              102
#define IDS_APMONITORCLASS              103
#define IDM_RESTORE                     104
#define IDM_EXIT                        105
#define IDI_APSRVMON                    106
#define IDI_ICOSTOP                     107
#define IDI_ICORUN                      108
#define IDC_STATBAR                     109
#define IDC_SSTATUS                     110
#define IDB_BMPSTOP                     111
#define IDB_BMPRUN                      112
#define IDB_BMPHEADER                   113
#define IDL_SERVICES                    114
#define IDL_STDOUT                      115
#define IDC_SSTART                      116
#define IDC_SSTOP                       117
#define IDC_SRESTART                    118
#define IDC_SEXIT                       119
#define IDC_SMANAGER                    120
#define IDD_DLGCONNECT                  121
#define IDC_LREMOTE                     122
#define IDC_COMPUTER                    123
#define IDC_SCONNECT                    124
#define IDS_MSG_FIRST                   256
#define IDS_MSG_APPRUNNING              256
#define IDS_MSG_ERROR                   257
#define IDS_MSG_RUNNINGALL              258
#define IDS_MSG_RUNNING                 259
#define IDS_MSG_RUNNINGNONE             260
#define IDS_MSG_NOSERVICES              261
#define IDS_MSG_MNUSERVICES             262
#define IDS_MSG_MNUSHOW                 263
#define IDS_MSG_MNUEXIT                 264
#define IDS_MSG_SRVSTART                265
#define IDS_MSG_SRVSTARTED              266
#define IDS_MSG_SRVSTOP                 267
#define IDS_MSG_SRVSTOPPED              268
#define IDS_MSG_SRVRESTART              269
#define IDS_MSG_SRVRESTARTED            270
#define IDS_MSG_SRVFAILED               271
#define IDS_MSG_SSTART                  272
#define IDS_MSG_SSTOP                   273
#define IDS_MSG_SRESTART                274
#define IDS_MSG_SERVICES                275
#define IDS_MSG_CONNECT                 276
#define IDS_MSG_ECONNECT                277
#define IDS_MSG_LAST                    277
#define IDM_SM_SERVICE                  0x1100
#define IDM_SM_START                    0x1200
#define IDM_SM_STOP                     0x1400
#define IDM_SM_RESTART                  0x1800
#define IDC_STATIC                      -1
